@@ -225,7 +225,7 @@ class Crp:
         
         # First, perform initial cleaning and save a log file of action
     
-        df,log_file = getCleanData(original_dataset)
+        df,log_file = self.getCleanData(original_dataset)
         # Get the first matrices
         train_data = self.getTrainingframe(df,dateFlag_sep,date_flag_min)
         print('train_data Done')
